@@ -51,7 +51,11 @@ class BaseRelinkActionWithFieldsOverwrite(BaseRelinkAction):
             for obj, instance in zip(objects, instances):
                 if instance and instance is not DISCARD_OBJECT:
                     assert obj.fields is not None
-                    fields = {k: v for k, v in obj.fields.items() if k in self.overwrite_fields}
+
+                    if self.overwrite_fields == ('__all__',):
+                        fields = {k: v for k, v in obj.fields.items() if k not in ['pk', 'id']}
+                    else:
+                        fields = {k: v for k, v in obj.fields.items() if k in self.overwrite_fields}
                     _assign_model_fields(instance, fields, policy)
                     instance.save()
 
